@@ -5,11 +5,11 @@ import logging
 
 kafka_decorator_debug = None
 
-def setDebugLevel( val ):
+def set_debug_level( val ):
     global kafka_decorator_debug
     kafka_decorator_debug = val
 
-def getLogger( name ):
+def get_logger( name ):
     global kafka_decorator_debug
     logger = logging.getLogger(name)
     if kafka_decorator_debug is not None:
